@@ -44,7 +44,7 @@ int32_t SPVM__Regex__compile(SPVM_ENV* env, SPVM_VALUE* stack) {
     return env->die(env, stack, "The regex pattern %s can't be compiled. [Error]%s. [Fragment]%s", pattern, error.data(), error_arg.data(), __func__, FILE_NAME, __LINE__);
   }
   
-  void* obj_re2 = env->new_pointer_object_by_name(env, stack, "Regex::Re2", re2.release(), &error_id, __func__, FILE_NAME, __LINE__);
+  void* obj_re2 = env->new_pointer_object_by_name(env, stack, "Regex::RE2", re2.release(), &error_id, __func__, FILE_NAME, __LINE__);
   if (error_id) { return error_id; }
   
   env->set_field_object_by_name(env, stack, obj_self, "re2", obj_re2, &error_id, __func__, FILE_NAME, __LINE__);
@@ -69,6 +69,12 @@ int32_t SPVM__Regex__match_forward(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t string_length = env->length(env, stack, obj_string);
   
   int32_t* offset_ref = stack[2].iref;
+  
+  if (!offset_ref) {
+    int32_t offset_tmp = 0;
+    offset_ref = &offset_tmp;
+  }
+  
   int32_t offset = *offset_ref;
   if (offset < 0) {
     return env->die(env, stack, "The string offset must be greater than or equal to 0", __func__, FILE_NAME, __LINE__);
@@ -115,20 +121,12 @@ int32_t SPVM__Regex__match_forward(SPVM_ENV* env, SPVM_VALUE* stack) {
         if (i == 0) {
           match_start = (submatch[0].data() - string);
           match_length = submatch[0].length();
-          
-          env->set_field_int_by_name(env, stack, obj_self, "match_start", match_start, &error_id, __func__, FILE_NAME, __LINE__);
-          if (error_id) { return error_id; }
-          
-          env->set_field_int_by_name(env, stack, obj_self, "match_length", match_length, &error_id, __func__, FILE_NAME, __LINE__);
-          if (error_id) { return error_id; }
         }
         else {
           void* obj_capture = env->new_string(env, stack, submatch[i].data(), submatch[i].length());
           env->set_elem_object(env, stack, obj_captures, i, obj_capture);
         }
       }
-      env->set_field_object_by_name(env, stack, obj_self, "captures", obj_captures, &error_id, __func__, FILE_NAME, __LINE__);
-      if (error_id) { return error_id; }
     }
     
     {
