@@ -1,6 +1,6 @@
 package SPVM::Regex;
 
-our $VERSION = "0.245";
+our $VERSION = "0.246";
 
 1;
 
@@ -17,7 +17,20 @@ The Regex class of L<SPVM> has methods for regular expressions.
 L<Google RE2|https://github.com/google/re2> is used as the regular expression library.
 
 =head1 Usage
+
+B<Re:>
+
+  use Re;
   
+  my $string = "Hello World"
+  my $match = Re->m($string, "^Hellow");
+  
+  # ABC de ABC
+  my $string_ref = ["abc de abc"];
+  Re->s($string_ref, ["abc", "g"], "ABC");
+
+B<Regex:>
+
   use Regex;
   
   # Pattern match
@@ -110,6 +123,12 @@ L<Google RE2|https://github.com/google/re2> is used as the regular expression li
     }
   }
 
+=head1 Details
+
+=head2 More Perlish Pattern Match and Replacement
+
+See L<Re|SPVM::Re> class if you want to use more Perlish pattern match and replacement.
+
 =head1 Dependent Resources
 
 =over 2
@@ -124,38 +143,6 @@ L<Google RE2 Syntax|https://github.com/google/re2/wiki/Syntax>
 
 =head1 Fields
 
-=head2 captures
-
-  has captures : ro string[];
-
-The captured strings.
-
-This field is deprecated and will be removed.
-
-=head2  match_start
-
-  has match_start : ro int;
-
-The start offset of the matched string.
-
-This field is deprecated and will be removed.
-
-=head2 match_length
-
-  has match_length : ro int;
-
-The length of the matched string.
-
-This field is deprecated and will be removed.
-
-=head2 replaced_count
-
-  has replaced_count : ro int;
-
-The replaced count.
-
-This field is deprecated and will be removed.
-
 =head1 Class Methods
 
 =head2 new
@@ -304,164 +291,6 @@ The same as L</"replace_common">, but the first argument is a L<StringBuffer|SPV
 
 The replacement is performed on the string buffer.
 
-=head2 cap1
-
-  method cap1 : string ();
-
-The alias for C<$re-E<gt>captures-E<gt>[1]>.
-
-This method is deprecated and will be removed.
-
-=head2 cap2
-
-  method cap2 : string ();
-
-The alias for C<$re-E<gt>captures-E<gt>[2]>.
-
-This method is deprecated and will be removed.
-
-=head2 cap3
-
-  method cap3 : string ();
-
-The alias for C<$re-E<gt>captures-E<gt>[3]>.
-
-This method is deprecated and will be removed.
-
-=head2 cap4
-
-  method cap4 : string ();
-
-The alias for C<$re-E<gt>captures-E<gt>[4]>.
-
-This method is deprecated and will be removed.
-
-=head2 cap5
-
-  method cap5 : string ();
-
-The alias for C<$re-E<gt>captures-E<gt>[5]>.
-
-This method is deprecated and will be removed.
-
-=head2 cap6
-
-  method cap6 : string ();
-
-The alias for C<$re-E<gt>captures-E<gt>[6]>.
-
-This method is deprecated and will be removed.
-
-=head2 cap7
-
-  method cap7 : string ();
-
-The alias for C<$re-E<gt>captures-E<gt>[7]>.
-
-This method is deprecated and will be removed.
-
-=head2 cap8
-
-  method cap8 : string ();
-
-The alias for C<$re-E<gt>captures-E<gt>[8]>.
-
-This method is deprecated and will be removed.
-
-=head2 cap9
-
-  method cap9 : string ();
-The alias for C<$re-E<gt>captures-E<gt>[9]>.
-
-This method is deprecated and will be removed.
-
-=head2 cap10
-
-  method cap10 : string ();
-The alias for C<$re-E<gt>captures-E<gt>[10]>.
-
-This method is deprecated and will be removed.
-
-=head2 cap11
-
-  method cap11 : string ();
-
-The alias for C<$re-E<gt>captures-E<gt>[11]>.
-
-This method is deprecated and will be removed.
-
-=head2 cap12
-
-  method cap12 : string ();
-
-The alias for C<$re-E<gt>captures-E<gt>[12]>.
-
-This method is deprecated and will be removed.
-
-=head2 cap13
-
-  method cap13 : string ();
-
-The alias for C<$re-E<gt>captures-E<gt>[13]>.
-
-This method is deprecated and will be removed.
-
-=head2 cap14
-
-  method cap14 : string ();
-
-The alias for C<$re-E<gt>captures-E<gt>[14]>.
-
-This method is deprecated and will be removed.
-
-=head2 cap15
-
-  method cap15 : string ();
-
-The alias for C<$re-E<gt>captures-E<gt>[15]>.
-
-This method is deprecated and will be removed.
-
-=head2 cap16
-
-  method cap16 : string ();
-
-The alias for C<$re-E<gt>captures-E<gt>[16]>.
-
-This method is deprecated and will be removed.
-
-=head2 cap17
-
-  method cap17 : string ();
-
-The alias for C<$re-E<gt>captures-E<gt>[17]>.
-
-This method is deprecated and will be removed.
-
-=head2 cap18
-
-  method cap18 : string ();
-
-The alias for C<$re-E<gt>captures-E<gt>[18]>.
-
-This method is deprecated and will be removed.
-
-=head2 cap19
-
-  method cap19 : string ();
-
-The alias for C<$re-E<gt>captures-E<gt>[19]>.
-
-This method is deprecated and will be removed.
-
-=head2 cap20
-
-  method cap20 : string ();
-
-The alias for C<$re-E<gt>captures-E<gt>[20]>.
-
-This method is deprecated and will be removed.
-
 =head1 Repository
 
 L<SPVM::Regex - Github|https://github.com/yuki-kimoto/SPVM-Regex>
